==> gsa-26.0.0.tar.gz: gsa-26.0.0/src/web/pages/schedules/ScheduleFilterDialog.tsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import Filter from 'gmp/models/filter';
import DefaultFilterDialog from 'web/components/powerfilter/DefaultFilterDialog';
import FilterDialog from 'web/components/powerfilter/FilterDialog';
import useFilterDialog from 'web/components/powerfilter/useFilterDialog';
import useFilterDialogSave, {
  UseFilterDialogSaveProps,
  UseFilterDialogStateProps,
} from 'web/components/powerfilter/useFilterDialogSave';
import useTranslation from 'web/hooks/useTranslation';

interface SchedulesFilterDialogProps extends UseFilterDialogSaveProps {
  filter?: Filter;
}

const ScheduleFilterDialog = ({
  filter,
  onClose,
  onFilterChanged,
  onFilterCreated,
}: SchedulesFilterDialogProps) => {
  const [_] = useTranslation();
  const filterDialogProps = useFilterDialog<UseFilterDialogStateProps>(filter);
  const [handleSave] = useFilterDialogSave(
    'schedule',
    {
      onClose,
      onFilterChanged,
      onFilterCreated,
    },
    filterDialogProps,
  );
  const SORT_FIELDS = [
    {
      name: 'name',
      displayName: _('Name'),
    },
    {
      name: 'first_run',
      displayName: _('First Run'),
    },
    {
      name: 'next_run',
      displayName: _('Next Run'),
    },
    {
      name: 'period',
      displayName: _('Recurrence'),
    },
    {
      name: 'duration',
      displayName: _('Duration'),
    },
  ];
  return (
    <FilterDialog onClose={onClose} onSave={handleSave}>
      <DefaultFilterDialog {...filterDialogProps} sortFields={SORT_FIELDS} />
    </FilterDialog>
  );
};

export default ScheduleFilterDialog;

==> gsa-26.10.1.tar.gz: gsa-26.10.1/src/web/pages/schedules/ScheduleFilterDialog.tsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import type Filter from 'gmp/models/filter';
import DefaultFilterDialog from 'web/components/powerfilter/DefaultFilterDialog';
import FilterDialog from 'web/components/powerfilter/FilterDialog';
import useFilterDialog from 'web/components/powerfilter/useFilterDialog';
import useFilterDialogSave, {
  type UseFilterDialogSaveProps,
  type UseFilterDialogStateProps,
} from 'web/components/powerfilter/useFilterDialogSave';
import useTranslation from 'web/hooks/useTranslation';

interface SchedulesFilterDialogProps extends UseFilterDialogSaveProps {
  filter?: Filter;
}

const ScheduleFilterDialog = ({
  filter,
  onClose,
  onFilterChanged,
  onFilterCreated,
}: SchedulesFilterDialogProps) => {
  const [_] = useTranslation();
  const filterDialogProps = useFilterDialog<UseFilterDialogStateProps>(filter);
  const [handleSave] = useFilterDialogSave(
    'schedule',
    {
      onClose,
      onFilterChanged,
      onFilterCreated,
    },
    filterDialogProps,
  );
  const SORT_FIELDS = [
    {
      name: 'name',
      displayName: _('Name'),
    },
    {
      name: 'first_run',
      displayName: _('First Run'),
    },
    {
      name: 'next_run',
      displayName: _('Next Run'),
    },
    {
      name: 'period',
      displayName: _('Recurrence'),
    },
    {
      name: 'duration',
      displayName: _('Duration'),
    },
  ];
  return (
    <FilterDialog onClose={onClose} onSave={handleSave}>
      <DefaultFilterDialog {...filterDialogProps} sortFields={SORT_FIELDS} />
    </FilterDialog>
  );
};

export default ScheduleFilterDialog;
